# -*- coding: UTF-8 -*-
# Package:  circuits
# Date:     3rd October 2008
# Author:   James Mills, prologic at shortcircuit dot net dot au

"""circuits

Lightweight Event driven Framework

:copyright: CopyRight (C) 2004-2011 by James Mills
:license: MIT (See: LICENSE)
"""

__author__ = "James Mills"
__date__ = "1st February 2011"
__version__ = "1.3.2"

from core import *
